-- Function to create a plane from a bitmap's dimensions
fn createPlaneFromBitmap bitmap_file =
(
    -- Load the bitmap to get its dimensions
    local theBitmap = openBitmap bitmap_file

    -- Create a new plane with exact dimensions as the bitmap
    local newPlane = Plane width:theBitmap.width length:theBitmap.height name:(getFilenameFile bitmap_file) position:[0,0,0] isSelected:true realWorldMapSize:true

    -- Segmentation of the plane - You may comment out or delete these lines if you don't need segments
    newPlane.widthsegs = 1  -- No segmentation based on your requirement
    newPlane.lengthsegs = 1

    -- Setup Corona Physical Material with the bitmap as a diffuse map
    local coronaMat = CoronaPhysicalMtl()
    local correBitmap = CoronaBitmap filename:theBitmap.filename realWorldScale:true uvwscale:[theBitmap.width, theBitmap.height, 1]
    coronaMat.baseTexmap = correBitmap

    -- Close the bitmap as we no longer need it open
    close theBitmap

    -- Assign material to the plane
    newPlane.material = coronaMat

    -- Select only the newly created plane
    select newPlane

    -- Zoom Extents Selected in active viewport
    max zoomext sel

    newPlane -- return the plane object
)

-- Function to prompt the user to select a bitmap file and create a plane
fn loadBitmapAndCreatePlane =
(
    local bitmapFilePath = getOpenFileName caption:"Load Bitmap File" types:"Image Files|*.bmp;*.jpg;*.jpeg;*.png;*.tif;*.tiff;*.gif|All Files|*.*||"

    if bitmapFilePath != undefined do
    (
        createPlaneFromBitmap bitmapFilePath
    )
)

-- Run the function to load bitmap and create plane
loadBitmapAndCreatePlane()